@@ -25,6 +25,8 @@ from .exceptions import Async as AsyncError
 from .exceptions import Invalid
 from .tmp import Tmp
 
+#from .ext import commands # SHORTCUT-DISALLOWED
+
 # const
 prefix = colored('linelib v2', 'light_green')
 
@@ -256,6 +258,11 @@ class Client:
         if res == 'all-nf' and cog.show_not_found_log:
             print('\n' + colored('linelib v2', 'light_green') + " " + colored('COG', attrs=['bold', 'underline']) + f" - {cog.name}\n{' ' * len('linelib v2 ')}" + colored(f'Command \'{ctx.content.strip().split(" ")[0]}\' not found.', 'red') + '\n')
 
+    for event in cog.get_events():
+      print(event)
+      @self.event(event.event)
+      async def on_event(ctx):
+        await event.emit(cog, ctx)
     return ...
 
   load_extension = load_cog
@@ -269,4 +276,5 @@ class Client:
     await asyncio.sleep(seconds)
 
 
+
 # hello if ur on github
\ No newline at end of file
