@@ -21,7 +21,7 @@ async def reply(client: type, rt: str, msgs: list, disabled: bool):
         "messages": msgs,
         "notificationDisabled": disabled
       })
-      print(r.json()) # Dev
+      #print(r.json()) # Dev
       resJson = r.json()
       mk(resJson)
       return r
